@@ -367,7 +367,7 @@ VALUE make_normal_type_instance(VALUE normal_type) {
 	return ret;
 }
 
-METHOD_RESULT get_normal_type_instace_field(VALUE obj, VALUE field, VALUE *result) {
+METHOD_RESULT get_normal_type_instance_field(VALUE obj, VALUE field, VALUE *result) {
 	VALUE ut;
 	HASH_OBJECT_ENTRY *e;
 	size_t n;
@@ -1012,6 +1012,7 @@ json_object *_encode_json_kern(VALUE obj, VALUE *result) {
 		for(e=HASH_HEAD(obj); e; e=e->insertion_order_next) {
 			if(!IS_STRING(e->key)) {
 				*result = make_string("Hash keys must be strings");
+				return NULL;
 			}
 			v = _encode_json_kern(e->val, result);
 			if(!IS_UNDEF(*result)) return NULL; // Exception occurred
@@ -1172,6 +1173,38 @@ VALUE make_DIR() {
 	return v;
 }
 
+VALUE make_sockaddr() {
+	VALUE v;
+	SOCKADDR_OBJECT *sa;
+	sa = NGS_MALLOC_ATOMIC(sizeof(*sa));
+	memset(&sa->val, 0, sizeof(sa->val));
+	sa->base.type.num = T_SOCKADDR;
+	SET_OBJ(v, sa);
+	return v;
+}
+
+VALUE make_sockaddr_un() {
+	VALUE v;
+	SOCKADDR_UN_OBJECT *sa;
+	sa = NGS_MALLOC_ATOMIC(sizeof(*sa));
+	memset(&sa->val, 0, sizeof(sa->val));
+	sa->base.type.num = T_SOCKADDR_UN;
+	SET_OBJ(v, sa);
+	return v;
+}
+
+VALUE make_sockaddr_in() {
+	VALUE v;
+	SOCKADDR_IN_OBJECT *sa;
+	sa = NGS_MALLOC_ATOMIC(sizeof(*sa));
+	memset(&sa->val, 0, sizeof(sa->val));
+	sa->base.type.num = T_SOCKADDR_IN;
+	SET_OBJ(v, sa);
+	return v;
+}
+
+
+
 VALUE resolve_instruction_pointer(VM *vm, IP ip) {
 	// Find region
 	// TODO: Something faster then sequential scan
