@@ -195,6 +195,7 @@ struct VM {
 				VALUE FieldNotFound;
 				VALUE GlobalNotFound;
 			VALUE UndefinedLocalVar;
+			VALUE UndefinedUpVar;
 			VALUE InvalidArgument;
 				VALUE DivisionByZero;
 			VALUE CompileFail;
@@ -254,6 +255,11 @@ struct VM {
 
 	VALUE c_ffi_type_string;
 
+	// networking
+	VALUE c_sockaddr;
+	VALUE c_sockaddr_un;
+	VALUE c_sockaddr_in;
+
 };
 
 
